import _extends from "@babel/runtime/helpers/esm/extends";
import { useState, useEffect, useRef } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import markerFactory from './markerFactory.js';
import Handler from './Handler.js';
import { Slider, Range, Label, BASE_CLASS, CLASS_DISABLED, CLASS_INVERSE } from './settings.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

var AtomSlider = function AtomSlider(_ref) {
  var _cx, _cx2;

  var onChange = _ref.onChange,
      onAfterChange = _ref.onAfterChange,
      value = _ref.value,
      _ref$min = _ref.min,
      min = _ref$min === void 0 ? 0 : _ref$min,
      _ref$max = _ref.max,
      max = _ref$max === void 0 ? 100 : _ref$max,
      _ref$step = _ref.step,
      step = _ref$step === void 0 ? 1 : _ref$step,
      range = _ref.range,
      disabled = _ref.disabled,
      valueLabel = _ref.valueLabel,
      marks = _ref.marks,
      valueLabelFormatter = _ref.valueLabelFormatter,
      _ref$hideMarks = _ref.hideMarks,
      hideMarks = _ref$hideMarks === void 0 ? false : _ref$hideMarks,
      _ref$hideTooltip = _ref.hideTooltip,
      hideTooltip = _ref$hideTooltip === void 0 ? false : _ref$hideTooltip,
      defaultValue = _ref.defaultValue,
      invertColors = _ref.invertColors;
  var initialStateValue;
  var refAtomSlider = useRef();
  var numMax = Number(max);
  var numMin = Number(min);

  if (value !== undefined) {
    initialStateValue = range ? value.map(Number) : Number(value);
  } else if (defaultValue !== undefined) {
    initialStateValue = range ? defaultValue.map(Number) : Number(defaultValue);
  } else {
    initialStateValue = range ? [numMin, numMax] : Math.trunc((numMin + numMax - numMin) / 2);
  }

  var _useState = useState(initialStateValue),
      internalValue = _useState[0],
      setInternalValue = _useState[1];

  useEffect(function () {
    if (value !== undefined) {
      setInternalValue(range ? value.map(Number) : Number(value));
    }
  }, [value, range]);

  var handleChange = function handleChange(newValue) {
    var e = {};

    if (value === undefined) {
      setInternalValue(newValue);
    }

    if (typeof onChange === 'function') {
      onChange(e, {
        value: newValue
      });
    }
  };

  var handleAfterChange = function handleAfterChange(value) {
    if (typeof onAfterChange === 'function') {
      onAfterChange({}, {
        value: value
      });
    }
  };

  var customProps = {
    handle: function handle(props) {
      return /*#__PURE__*/_jsx(Handler, _extends({
        refAtomSlider: refAtomSlider,
        hideTooltip: hideTooltip
      }, props));
    },
    onChange: handleChange,
    onAfterChange: handleAfterChange,
    disabled: disabled,
    marks: hideMarks ? {} : markerFactory({
      step: step,
      min: min,
      max: max,
      marks: marks
    }),
    max: max,
    min: min,
    step: step,
    value: internalValue
  }; // Determine the type of the slider according to the range prop

  var Type = range ? Range : Slider;
  return /*#__PURE__*/_jsx("div", {
    ref: refAtomSlider,
    className: cx(BASE_CLASS, (_cx = {}, _cx[CLASS_DISABLED] = disabled, _cx), (_cx2 = {}, _cx2[CLASS_INVERSE] = invertColors, _cx2)),
    children: valueLabel && customProps.handle ? /*#__PURE__*/_jsxs(_Fragment, {
      children: [/*#__PURE__*/_jsx(Label, {
        value: internalValue.toString(),
        formatter: valueLabelFormatter,
        percentage: (internalValue - min) / (max - min) * 100
      }), /*#__PURE__*/_jsx(Type, _extends({}, customProps))]
    }) : /*#__PURE__*/_jsx(Type, _extends({}, customProps))
  });
};

AtomSlider.displayName = 'AtomSlider';
export default AtomSlider;